@@ -3,6 +3,8 @@ from typing import Union, Optional, Dict
 from humps import camelize
 from pydantic import BaseModel
 
+CursorIdType = Union[int, str]
+
 
 def to_camel_case(string: str) -> str:
     return camelize(string)
@@ -24,7 +26,7 @@ class BaseSerializer(BaseModel):
 
 
 class PageMetadata(BaseSerializer):
-    next_cursor_id: Optional[int]
+    next_cursor_id: Optional[CursorIdType]
 
 
 class PaginatedResponse(BaseSerializer):
